@@ -11,6 +11,12 @@ try:
     from configparser import ConfigParser
 except ImportError:
     from ConfigParser import SafeConfigParser as ConfigParser
+    def _convert_to_boolean(self, v):
+        if v.lower() not in self._boolean_states:
+            raise(ValueError, 'Not a boolean: %s' % v)
+        return self._boolean_states[v.lower()]
+    ConfigParser._convert_to_boolean = _convert_to_boolean
+
 
 import plac
 
@@ -93,6 +99,7 @@ def add_gnu_argument(self, *args, **kwargs):
 
     argparse.ArgumentParser.add_argument(self, *gnu_args, **kwargs)
 
+
 def _print_exit(message, file=None):
     if message:
         if file is None:
@@ -100,6 +107,7 @@ def _print_exit(message, file=None):
         file.write(message)
     sys.exit(2)
 
+
 def call(obj, arglist=sys.argv[1:], eager=True, config=None,
          default_section=None, gnu=True):
     if gnu:
@@ -138,6 +146,7 @@ def call(obj, arglist=sys.argv[1:], eager=True, config=None,
                             argparser.prog, k, ini_values[k], a.type, config))
 
     cfg.update(ini_values)
+    obj.plac_cfg = cfg
 
     if sys.version >= '3':
         items = cfg.items()
